@@ -26,7 +26,7 @@ our $CACHE;
 
 use vars qw($VERSION);
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 
 # ------------------------------------------------------------------------------------------
@@ -93,6 +93,14 @@ sub first_id {
     return $DATASTORE->first_id();
 }
 
+sub flush {
+    my( $id ) = @_;
+    delete $Yote::ObjProvider::DIRTY->{$id};
+    delete $Yote::ObjProvider::WEAK_REFS->{$id};
+    delete $Yote::ObjProvider::DIRTY->{$id};
+    $CACHE->flush( $id );
+}
+
 sub fetch {
     my( $id ) = @_;
 
@@ -552,6 +560,10 @@ Requests the data store used disconnect.
 
 Returns a string of the argument encrypted.
 
+=item flush( id )
+
+Removes any object with the given ID from any cache
+
 =item fetch( id )
 
 Returns the array ref, hash ref or yote object specified by the numeric id or hash path.
